CSA combination โ block cipher + stream cipher.
DVB-CSA2 encrypt/decrypt consists of two phases applied in a specific order:
Encrypt (scramble):
- Block-cipher CBC: encrypt the last block first, then work backward, XORing each plaintext block into the next before encrypting.
- Stream-cipher XOR: seed from the (now-encrypted) first block, XOR bytes 8..end.
Decrypt (descramble):
- Stream-cipher XOR: seed from the (still-encrypted) first block, XOR bytes 8..end.
- Block-cipher CBC undo: decrypt first block, then work forward, XORing each decrypted block into the next before decrypting.
Payloads shorter than 8 bytes are passed through unchanged.
Functions
- descramble
- Descramble (decrypt)
datain-place with the given control word. - scramble
- Scramble (encrypt)
datain-place with the given control word.